
__doc__='''VlabMonitorDataSource.py

Defines datasource for VlabMonitor
'''

import Products.ZenModel.BasicDataSource as BasicDataSource
from Products.ZenModel.ZenPackPersistence import ZenPackPersistence
from AccessControl import ClassSecurityInfo, Permissions
from Products.ZenUtils.ZenTales import talesCompile, getEngine

import os

class VlabMonitorDataSource(ZenPackPersistence,
                                BasicDataSource.BasicDataSource):
    VLAB_MONITOR = 'VlabMonitor'
    
    ZENPACKID = 'ZenPacks.SkyTap.VlabMonitor'

    sourcetypes = (VLAB_MONITOR,)
    sourcetype = VLAB_MONITOR

    timeout = 15
    eventClass = '/Status/Web'

    hostname = '${dev/manageIp}'
    port = '80'
    url = '/server-status?auto'

    _properties = BasicDataSource.BasicDataSource._properties + (
            {'id':'timeout', 'type':'int', 'mode':'w'},
            {'id':'eventClass', 'type':'string', 'mode':'w'},
            {'id':'hostname', 'type':'string', 'mode':'w'},
            )

    _relations = BasicDataSource.BasicDataSource._relations + (
            )

    factory_type_information = (
        {
            'immediate_view': 'editVlabMonitorDataSource',
            'actions':
            (
                { 'id': 'edit',
                  'name': 'Data Source',
                  'action': 'editVlabMonitorDataSource',
                  'permissions': ( Permissions.view ),
                },
            )
        },
    )

    security = ClassSecurityInfo()


    def __init__(self, id, title=None, buildRelations=True):
        BasicDataSource.BasicDataSource.__init__(self, id, title,
                buildRelations)


    def getDescription(self):
        if self.sourcetype == self.VLAB_MONITOR:
            return self.hostname
        return BasicDataSource.BasicDataSource.getDescription(self)


    def useZenCommand(self):
        return True


    def getCommand(self, context):
        parts = ['check_vlab.py']
        if self.hostname:
            parts.append('-H %s' % self.hostname)
        cmd = ' '.join(parts)
        cmd = BasicDataSource.BasicDataSource.getCommand(self, context, cmd)
        return cmd

    def checkCommandPrefix(self, context, cmd):
        zp = self.getZenPack(context)
        return zp.path('libexec', cmd)


    def addDataPoints(self):
        for dpname in ('vm_session_poll_hits',
                       'static_hits',
                       'everything_else_hits',
                       'configuration_popup_menu_check_hits',
                       'upload_hits'):

            dp = self.manage_addRRDDataPoint(dpname)
            dp.rrdtype = 'COUNTER'
            dp.rrdmin = 0
            
        for dpname in ('vm_session_poll_max_latency',
                       'static_max_latency',
                       'everything_else_max_latency',
                       'configuration_popup_menu_check_max_latency',
                       'upload_max_latency'):
            dp = self.manage_addRRDDataPoint(dpname)
            dp.rrdtype = 'GAUGE'
            dp.rrdmin = 0
            
        for dpname in ('vm_session_poll_max_latency',
                       'static_max_latency',
                       'everything_else_max_latency',
                       'configuration_popup_menu_check_max_latency',
                       'upload_max_latency'):
            dp = self.manage_addRRDDataPoint(dpname)
            dp.rrdtype = 'GAUGE'
            dp.rrdmin = 0

        for dpname in ('vm_session_poll_av_lat',
                       'static_av_lat',
                       'everything_else_av_lat',
                       'configuration_popup_menu_check_av_lat',
                       'upload_av_lat'):
            dp = self.manage_addRRDDataPoint(dpname)
            dp.rrdtype = 'GAUGE'
            dp.rrdmin = 0


    def zmanage_editProperties(self, REQUEST=None):
        '''validation, etc'''
        if REQUEST:
            self.addDataPoints()
            if not REQUEST.form.get('eventClass', None):
                REQUEST.form['eventClass'] = self.__class__.eventClass
        return BasicDataSource.BasicDataSource.zmanage_editProperties(self,
                REQUEST)

