#!/usr/bin/env python
###########################################################################
#
# This program is part of Zenoss Core, an open source monitoring platform.
# Copyright (C) 2007, Zenoss Inc.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 2 as published by
# the Free Software Foundation.
#
# For complete information please visit: http://www.zenoss.com/oss/
#
###########################################################################

from optparse import OptionParser
import sys
import httplib
import re

class ZenossVlabStatsPlugin:
    def __init__(self, host):
        self.host = host

    def run(self):
        metrics = {}

        conn = httplib.HTTPSConnection(self.host)
        try:
            conn.request('GET', "/stats.txt")
            response = conn.getresponse()
            if response.status != 200:
                print 'Server replied: %d %s to action GET /stats.txt' % (
                        response.status, response.reason)
                sys.exit(1)

            stats_dict = eval(response.read())

            if stats_dict and stats_dict.get('vm_session_poll'):
                metrics['vm_session_poll_hits'] = \
                              stats_dict['vm_session_poll']['hits']
                metrics['vm_session_poll_av_lat'] = \
                          stats_dict['vm_session_poll']['latency'] / \
                          stats_dict['vm_session_poll']['this_period_hits']
                metrics['vm_session_poll_max_latency'] = \
                          stats_dict['vm_session_poll']['max_latency']
            else:
                metrics['vm_session_poll_hits'] = 0
                metrics['vm_session_poll_av_lat'] = 0
                metrics['vm_session_poll_max_latency'] = 0

            if stats_dict and stats_dict.get('static'):
                metrics['static_hits'] = \
                              stats_dict['static']['hits']
                metrics['static_av_lat'] = \
                          stats_dict['static']['latency'] / \
                          stats_dict['static']['this_period_hits']
                metrics['static_max_latency'] = \
                          stats_dict['static']['max_latency']
            else:
                metrics['static_hits'] = 0
                metrics['static_av_lat'] = 0
                metrics['static_max_latency'] = 0

            if stats_dict and stats_dict.get('everything_else'):
                metrics['everything_else_hits'] = \
                              stats_dict['everything_else']['hits']
                metrics['everything_else_av_lat'] = \
                          stats_dict['everything_else']['latency'] / \
                          stats_dict['everything_else']['this_period_hits']
                metrics['everything_else_max_latency'] = \
                          stats_dict['everything_else']['max_latency']
            else:
                metrics['everything_else_hits'] = 0
                metrics['everything_else_av_lat'] = 0
                metrics['everything_else_max_latency'] = 0
                
            if stats_dict and stats_dict.get('configuration_popup_menu_check'):
                metrics['configuration_popup_menu_check_hits'] = \
                              stats_dict['configuration_popup_menu_check']['hits']
                metrics['configuration_popup_menu_check_av_lat'] = \
                          stats_dict['configuration_popup_menu_check']['latency'] / \
                          stats_dict['configuration_popup_menu_check']['this_period_hits']
                metrics['configuration_popup_menu_check_max_latency'] = \
                          stats_dict['configuration_popup_menu_check']['max_latency']
            else:
                metrics['configuration_popup_menu_check_hits'] = 0
                metrics['configuration_popup_menu_check_av_lat'] = 0
                metrics['configuration_popup_menu_check_max_latency'] = 0
            
            if stats_dict and stats_dict.get('upload'):
                metrics['upload_hits'] = \
                              stats_dict['upload']['hits']
                metrics['upload_av_lat'] = \
                          stats_dict['upload']['latency'] / \
                          stats_dict['upload']['this_period_hits']
                metrics['upload_max_latency'] = \
                          stats_dict['upload']['max_latency']
            else:
                metrics['upload_hits'] = 0
                metrics['upload_av_lat'] = 0
                metrics['upload_max_latency'] = 0

        except SystemExit:
            sys.exit(1)
        except Exception, e:
            print "Error: %s" % (e,)
            sys.exit(1)

        print "STATUS OK|%s" % (' '.join([ "%s=%s" % (m[0],m[1]) \
            for m in metrics.items() ]))

if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option('-H', '--host', dest='host',
        help='Hostname of Vlab server')
    options, args = parser.parse_args()

    if not options.host:
        print "You must specify the host parameter."
        sys.exit(1)

    cmd = ZenossVlabStatsPlugin(options.host)
    cmd.run()
